@@ -11,11 +11,13 @@ def translate_prepare_node(region, account_id, cytoscape_node_data):
             print('Found a cloudtrail translate file')
             cytoscape_node_data.append({
                 "data": {
-                    "type": "translate",
+                    "type": "Translate",
                     "id": "translate",
                     "region": region,
                     "account_id": account_id,
                     "name": "translate",
+                    "cost_for_month": "15.00 USD",
+                    "tag": {}
                 }
             })
             break
